A replacement for the macOS `say` command, with plans for multiple backends.

This project is a stub and a placeholder under heavy development, and is not intended for usage yet. Stay tuned.

# gensay

[![PyPI - Version](https://img.shields.io/pypi/v/gensay.svg)](https://pypi.org/project/gensay)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/gensay.svg)](https://pypi.org/project/gensay)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

It's 2025, use [uv](https://github.com/astral-sh/uv)

`gensay` is intended to be used as a CLI tool that is a drop-in replacement to the macOS `say` CLI.

```console
uv pip tool install gensay
```

Wherever you used `say` in your prior projects, just globally replace the command mention with `gensay`.

You can also use it from your Python apps by `uv add gensay` to your project.

## License

`gensay` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
